RoutingArguments class

Constructors

RoutingArguments({String? route, Map<String, String>? query})
RoutingArguments initialization

Properties

hashCode int
The hash code for this object.
no setterinherited
isCurrent bool
Have to use RoutingArguments.of(context) for this to work
getter/setter pair
route String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) String?
Using [] operator gets value from query for key

Static Methods

of(BuildContext context) RoutingArguments?
RoutingArguments from current ModalRoute