MainDataProviderOptions class
Constructors
- MainDataProviderOptions({MockUpOptions? mockUpOptions, HTTPClientOptions? httpClientOptions, SQLiteOptions? sqLiteOptions, SembastOptions? sembastOptions})
- MainDataProviderOptions initialization
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClientOptions ↔ HTTPClientOptions?
-
getter/setter pair
- mockUpOptions ↔ MockUpOptions?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sembastOptions ↔ SembastOptions?
-
getter/setter pair
- sqLiteOptions ↔ SQLiteOptions?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited