MockUpSource class
- Inheritance
-
- Object
- AbstractSource
- MockUpSource
Constructors
- MockUpSource({required MockUpOptions options})
- MockUpSource initialization
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSource → MainDataProviderSource
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ ValueNotifier<
MainDataProviderSourceState> -
getter/setter pairinherited
Methods
-
dataRequestHasNextPage(
DataRequest< DataModel> dataRequest) → Future<bool> -
Check if DataRequest has next page
Mockup does not support pagination
override
-
dataRequestLoadNextPage(
DataRequest< DataModel> dataRequest) → void -
Request to load next page of DataRequest
override
-
executeDataTask<
T extends DataTask< (DataModel, DataModel> >T dataTask) → Future< T> -
Execute one time DataTask against the source
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reFetchData(
{List< String> ? methods, List<String> ? identifiers}) → Future<void> -
ReFetch data for DataRequest based on methods or identifiers
override
-
registerDataRequests(
MainDataSource dataSource) → void -
Register DataSource DataRequests for identifiers and example DataRequests mapping
inherited
-
registerDataSource(
MainDataSource dataSource) → void -
Register the DataSource for data
override
-
sourceForTaskOptions(
DataTaskOptions options) → MainDataProviderSource -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unRegisterDataRequests(
MainDataSource dataSource) → void -
UnRegister DataSource DataRequests for identifiers if no other DataSource has equal
inherited
-
unRegisterDataSource(
MainDataSource dataSource) → void -
UnRegister the DataSource from receiving data
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited