Preferences class
Constructors
- Preferences({required PreferencesOptions options})
- Preferences initialization
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBool(
String key) → bool? - Get bool value for key from prefs
-
getDouble(
String key) → double? - Get double value for key from prefs
-
getInt(
String key) → int? - Get int value for key from prefs
-
getString(
String key) → String? - Get string value for key from prefs
-
init(
) → Future< void> - Initialize preferences from their storage
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeBool(
String key) → Future< bool> - Remove bool value for key
-
removeDouble(
String key) → Future< bool> - Remove double value for key
-
removeInt(
String key) → Future< bool> - Remove int value for key
-
removeString(
String key) → Future< bool> - Remove string value for key
-
setBool(
String key, bool value) → Future< bool> - Set bool value for key to prefs
-
setDouble(
String key, double value) → Future< bool> - Set double value for key to prefs
-
setInt(
String key, int value) → Future< bool> - Set int value for key to prefs
-
setString(
String key, String value) → Future< bool> - Set string value for key to prefs
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → Preferences?
-
no setter