SQLiteTaskOptions class
- Inheritance
-
- Object
- DataTaskOptions
- SQLiteTaskOptions
Constructors
- SQLiteTaskOptions({required SQLiteType type, String idKey = 'id', String? rawQuery, List? rawArguments, String? groupBy, String? having, String? orderBy})
-
SQLiteTaskOptions initialization
const
Properties
- groupBy → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- having → String?
-
final
- idKey → String
-
final
- orderBy → String?
-
final
- rawArguments → List?
-
final
- rawQuery → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SQLiteType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited